Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type KubeflowV1Client
- func (c *KubeflowV1Client) MPIJobs(namespace string) MPIJobInterface
- func (c *KubeflowV1Client) MXJobs(namespace string) MXJobInterface
- func (c *KubeflowV1Client) PaddleJobs(namespace string) PaddleJobInterface
- func (c *KubeflowV1Client) PyTorchJobs(namespace string) PyTorchJobInterface
- func (c *KubeflowV1Client) RESTClient() rest.Interface
- func (c *KubeflowV1Client) TFJobs(namespace string) TFJobInterface
- func (c *KubeflowV1Client) XGBoostJobs(namespace string) XGBoostJobInterface
- type KubeflowV1Interface
- type MPIJobExpansion
- type MPIJobInterface
- type MPIJobsGetter
- type MXJobExpansion
- type MXJobInterface
- type MXJobsGetter
- type PaddleJobExpansion
- type PaddleJobInterface
- type PaddleJobsGetter
- type PyTorchJobExpansion
- type PyTorchJobInterface
- type PyTorchJobsGetter
- type TFJobExpansion
- type TFJobInterface
- type TFJobsGetter
- type XGBoostJobExpansion
- type XGBoostJobInterface
- type XGBoostJobsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KubeflowV1Client ¶
type KubeflowV1Client struct {
// contains filtered or unexported fields
}
KubeflowV1Client is used to interact with features provided by the kubeflow.org group.
func New ¶
func New(c rest.Interface) *KubeflowV1Client
New creates a new KubeflowV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*KubeflowV1Client, error)
NewForConfig creates a new KubeflowV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new KubeflowV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *KubeflowV1Client
NewForConfigOrDie creates a new KubeflowV1Client for the given config and panics if there is an error in the config.
func (*KubeflowV1Client) MPIJobs ¶
func (c *KubeflowV1Client) MPIJobs(namespace string) MPIJobInterface
func (*KubeflowV1Client) MXJobs ¶
func (c *KubeflowV1Client) MXJobs(namespace string) MXJobInterface
func (*KubeflowV1Client) PaddleJobs ¶
func (c *KubeflowV1Client) PaddleJobs(namespace string) PaddleJobInterface
func (*KubeflowV1Client) PyTorchJobs ¶
func (c *KubeflowV1Client) PyTorchJobs(namespace string) PyTorchJobInterface
func (*KubeflowV1Client) RESTClient ¶
func (c *KubeflowV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*KubeflowV1Client) TFJobs ¶
func (c *KubeflowV1Client) TFJobs(namespace string) TFJobInterface
func (*KubeflowV1Client) XGBoostJobs ¶
func (c *KubeflowV1Client) XGBoostJobs(namespace string) XGBoostJobInterface
type KubeflowV1Interface ¶
type KubeflowV1Interface interface {
RESTClient() rest.Interface
MPIJobsGetter
MXJobsGetter
PaddleJobsGetter
PyTorchJobsGetter
TFJobsGetter
XGBoostJobsGetter
}
type MPIJobExpansion ¶
type MPIJobExpansion interface{}
type MPIJobInterface ¶
type MPIJobInterface interface {
Create(ctx context.Context, mPIJob *v1.MPIJob, opts metav1.CreateOptions) (*v1.MPIJob, error)
Update(ctx context.Context, mPIJob *v1.MPIJob, opts metav1.UpdateOptions) (*v1.MPIJob, error)
UpdateStatus(ctx context.Context, mPIJob *v1.MPIJob, opts metav1.UpdateOptions) (*v1.MPIJob, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.MPIJob, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.MPIJobList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.MPIJob, err error)
MPIJobExpansion
}
MPIJobInterface has methods to work with MPIJob resources.
type MPIJobsGetter ¶
type MPIJobsGetter interface {
MPIJobs(namespace string) MPIJobInterface
}
MPIJobsGetter has a method to return a MPIJobInterface. A group's client should implement this interface.
type MXJobExpansion ¶
type MXJobExpansion interface{}
type MXJobInterface ¶
type MXJobInterface interface {
Create(ctx context.Context, mXJob *v1.MXJob, opts metav1.CreateOptions) (*v1.MXJob, error)
Update(ctx context.Context, mXJob *v1.MXJob, opts metav1.UpdateOptions) (*v1.MXJob, error)
UpdateStatus(ctx context.Context, mXJob *v1.MXJob, opts metav1.UpdateOptions) (*v1.MXJob, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.MXJob, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.MXJobList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.MXJob, err error)
MXJobExpansion
}
MXJobInterface has methods to work with MXJob resources.
type MXJobsGetter ¶
type MXJobsGetter interface {
MXJobs(namespace string) MXJobInterface
}
MXJobsGetter has a method to return a MXJobInterface. A group's client should implement this interface.
type PaddleJobExpansion ¶
type PaddleJobExpansion interface{}
type PaddleJobInterface ¶
type PaddleJobInterface interface {
Create(ctx context.Context, paddleJob *v1.PaddleJob, opts metav1.CreateOptions) (*v1.PaddleJob, error)
Update(ctx context.Context, paddleJob *v1.PaddleJob, opts metav1.UpdateOptions) (*v1.PaddleJob, error)
UpdateStatus(ctx context.Context, paddleJob *v1.PaddleJob, opts metav1.UpdateOptions) (*v1.PaddleJob, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.PaddleJob, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.PaddleJobList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.PaddleJob, err error)
PaddleJobExpansion
}
PaddleJobInterface has methods to work with PaddleJob resources.
type PaddleJobsGetter ¶
type PaddleJobsGetter interface {
PaddleJobs(namespace string) PaddleJobInterface
}
PaddleJobsGetter has a method to return a PaddleJobInterface. A group's client should implement this interface.
type PyTorchJobExpansion ¶
type PyTorchJobExpansion interface{}
type PyTorchJobInterface ¶
type PyTorchJobInterface interface {
Create(ctx context.Context, pyTorchJob *v1.PyTorchJob, opts metav1.CreateOptions) (*v1.PyTorchJob, error)
Update(ctx context.Context, pyTorchJob *v1.PyTorchJob, opts metav1.UpdateOptions) (*v1.PyTorchJob, error)
UpdateStatus(ctx context.Context, pyTorchJob *v1.PyTorchJob, opts metav1.UpdateOptions) (*v1.PyTorchJob, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.PyTorchJob, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.PyTorchJobList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.PyTorchJob, err error)
PyTorchJobExpansion
}
PyTorchJobInterface has methods to work with PyTorchJob resources.
type PyTorchJobsGetter ¶
type PyTorchJobsGetter interface {
PyTorchJobs(namespace string) PyTorchJobInterface
}
PyTorchJobsGetter has a method to return a PyTorchJobInterface. A group's client should implement this interface.
type TFJobExpansion ¶
type TFJobExpansion interface{}
type TFJobInterface ¶
type TFJobInterface interface {
Create(ctx context.Context, tFJob *v1.TFJob, opts metav1.CreateOptions) (*v1.TFJob, error)
Update(ctx context.Context, tFJob *v1.TFJob, opts metav1.UpdateOptions) (*v1.TFJob, error)
UpdateStatus(ctx context.Context, tFJob *v1.TFJob, opts metav1.UpdateOptions) (*v1.TFJob, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.TFJob, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.TFJobList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.TFJob, err error)
TFJobExpansion
}
TFJobInterface has methods to work with TFJob resources.
type TFJobsGetter ¶
type TFJobsGetter interface {
TFJobs(namespace string) TFJobInterface
}
TFJobsGetter has a method to return a TFJobInterface. A group's client should implement this interface.
type XGBoostJobExpansion ¶
type XGBoostJobExpansion interface{}
type XGBoostJobInterface ¶
type XGBoostJobInterface interface {
Create(ctx context.Context, xGBoostJob *v1.XGBoostJob, opts metav1.CreateOptions) (*v1.XGBoostJob, error)
Update(ctx context.Context, xGBoostJob *v1.XGBoostJob, opts metav1.UpdateOptions) (*v1.XGBoostJob, error)
UpdateStatus(ctx context.Context, xGBoostJob *v1.XGBoostJob, opts metav1.UpdateOptions) (*v1.XGBoostJob, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.XGBoostJob, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.XGBoostJobList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.XGBoostJob, err error)
XGBoostJobExpansion
}
XGBoostJobInterface has methods to work with XGBoostJob resources.
type XGBoostJobsGetter ¶
type XGBoostJobsGetter interface {
XGBoostJobs(namespace string) XGBoostJobInterface
}
XGBoostJobsGetter has a method to return a XGBoostJobInterface. A group's client should implement this interface.