Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TestJobLister ¶
type TestJobLister interface {
// List lists all TestJobs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.TestJob, err error)
// TestJobs returns an object that can list and get TestJobs.
TestJobs(namespace string) TestJobNamespaceLister
TestJobListerExpansion
}
TestJobLister helps list TestJobs. All objects returned here must be treated as read-only.
func NewTestJobLister ¶
func NewTestJobLister(indexer cache.Indexer) TestJobLister
NewTestJobLister returns a new TestJobLister.
type TestJobListerExpansion ¶
type TestJobListerExpansion interface{}
TestJobListerExpansion allows custom methods to be added to TestJobLister.
type TestJobNamespaceLister ¶
type TestJobNamespaceLister interface {
// List lists all TestJobs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.TestJob, err error)
// Get retrieves the TestJob from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.TestJob, error)
TestJobNamespaceListerExpansion
}
TestJobNamespaceLister helps list and get TestJobs. All objects returned here must be treated as read-only.
type TestJobNamespaceListerExpansion ¶
type TestJobNamespaceListerExpansion interface{}
TestJobNamespaceListerExpansion allows custom methods to be added to TestJobNamespaceLister.
Click to show internal directories.
Click to hide internal directories.