Documentation
¶
Index ¶
- type MPIJobLister
- type MPIJobListerExpansion
- type MPIJobNamespaceLister
- type MPIJobNamespaceListerExpansion
- type MXJobLister
- type MXJobListerExpansion
- type MXJobNamespaceLister
- type MXJobNamespaceListerExpansion
- type PaddleJobLister
- type PaddleJobListerExpansion
- type PaddleJobNamespaceLister
- type PaddleJobNamespaceListerExpansion
- type PyTorchJobLister
- type PyTorchJobListerExpansion
- type PyTorchJobNamespaceLister
- type PyTorchJobNamespaceListerExpansion
- type TFJobLister
- type TFJobListerExpansion
- type TFJobNamespaceLister
- type TFJobNamespaceListerExpansion
- type XGBoostJobLister
- type XGBoostJobListerExpansion
- type XGBoostJobNamespaceLister
- type XGBoostJobNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MPIJobLister ¶
type MPIJobLister interface {
// List lists all MPIJobs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.MPIJob, err error)
// MPIJobs returns an object that can list and get MPIJobs.
MPIJobs(namespace string) MPIJobNamespaceLister
MPIJobListerExpansion
}
MPIJobLister helps list MPIJobs. All objects returned here must be treated as read-only.
func NewMPIJobLister ¶
func NewMPIJobLister(indexer cache.Indexer) MPIJobLister
NewMPIJobLister returns a new MPIJobLister.
type MPIJobListerExpansion ¶
type MPIJobListerExpansion interface{}
MPIJobListerExpansion allows custom methods to be added to MPIJobLister.
type MPIJobNamespaceLister ¶
type MPIJobNamespaceLister interface {
// List lists all MPIJobs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.MPIJob, err error)
// Get retrieves the MPIJob from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.MPIJob, error)
MPIJobNamespaceListerExpansion
}
MPIJobNamespaceLister helps list and get MPIJobs. All objects returned here must be treated as read-only.
type MPIJobNamespaceListerExpansion ¶
type MPIJobNamespaceListerExpansion interface{}
MPIJobNamespaceListerExpansion allows custom methods to be added to MPIJobNamespaceLister.
type MXJobLister ¶
type MXJobLister interface {
// List lists all MXJobs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.MXJob, err error)
// MXJobs returns an object that can list and get MXJobs.
MXJobs(namespace string) MXJobNamespaceLister
MXJobListerExpansion
}
MXJobLister helps list MXJobs. All objects returned here must be treated as read-only.
func NewMXJobLister ¶
func NewMXJobLister(indexer cache.Indexer) MXJobLister
NewMXJobLister returns a new MXJobLister.
type MXJobListerExpansion ¶
type MXJobListerExpansion interface{}
MXJobListerExpansion allows custom methods to be added to MXJobLister.
type MXJobNamespaceLister ¶
type MXJobNamespaceLister interface {
// List lists all MXJobs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.MXJob, err error)
// Get retrieves the MXJob from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.MXJob, error)
MXJobNamespaceListerExpansion
}
MXJobNamespaceLister helps list and get MXJobs. All objects returned here must be treated as read-only.
type MXJobNamespaceListerExpansion ¶
type MXJobNamespaceListerExpansion interface{}
MXJobNamespaceListerExpansion allows custom methods to be added to MXJobNamespaceLister.
type PaddleJobLister ¶
type PaddleJobLister interface {
// List lists all PaddleJobs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.PaddleJob, err error)
// PaddleJobs returns an object that can list and get PaddleJobs.
PaddleJobs(namespace string) PaddleJobNamespaceLister
PaddleJobListerExpansion
}
PaddleJobLister helps list PaddleJobs. All objects returned here must be treated as read-only.
func NewPaddleJobLister ¶
func NewPaddleJobLister(indexer cache.Indexer) PaddleJobLister
NewPaddleJobLister returns a new PaddleJobLister.
type PaddleJobListerExpansion ¶
type PaddleJobListerExpansion interface{}
PaddleJobListerExpansion allows custom methods to be added to PaddleJobLister.
type PaddleJobNamespaceLister ¶
type PaddleJobNamespaceLister interface {
// List lists all PaddleJobs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.PaddleJob, err error)
// Get retrieves the PaddleJob from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.PaddleJob, error)
PaddleJobNamespaceListerExpansion
}
PaddleJobNamespaceLister helps list and get PaddleJobs. All objects returned here must be treated as read-only.
type PaddleJobNamespaceListerExpansion ¶
type PaddleJobNamespaceListerExpansion interface{}
PaddleJobNamespaceListerExpansion allows custom methods to be added to PaddleJobNamespaceLister.
type PyTorchJobLister ¶
type PyTorchJobLister interface {
// List lists all PyTorchJobs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.PyTorchJob, err error)
// PyTorchJobs returns an object that can list and get PyTorchJobs.
PyTorchJobs(namespace string) PyTorchJobNamespaceLister
PyTorchJobListerExpansion
}
PyTorchJobLister helps list PyTorchJobs. All objects returned here must be treated as read-only.
func NewPyTorchJobLister ¶
func NewPyTorchJobLister(indexer cache.Indexer) PyTorchJobLister
NewPyTorchJobLister returns a new PyTorchJobLister.
type PyTorchJobListerExpansion ¶
type PyTorchJobListerExpansion interface{}
PyTorchJobListerExpansion allows custom methods to be added to PyTorchJobLister.
type PyTorchJobNamespaceLister ¶
type PyTorchJobNamespaceLister interface {
// List lists all PyTorchJobs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.PyTorchJob, err error)
// Get retrieves the PyTorchJob from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.PyTorchJob, error)
PyTorchJobNamespaceListerExpansion
}
PyTorchJobNamespaceLister helps list and get PyTorchJobs. All objects returned here must be treated as read-only.
type PyTorchJobNamespaceListerExpansion ¶
type PyTorchJobNamespaceListerExpansion interface{}
PyTorchJobNamespaceListerExpansion allows custom methods to be added to PyTorchJobNamespaceLister.
type TFJobLister ¶
type TFJobLister interface {
// List lists all TFJobs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.TFJob, err error)
// TFJobs returns an object that can list and get TFJobs.
TFJobs(namespace string) TFJobNamespaceLister
TFJobListerExpansion
}
TFJobLister helps list TFJobs. All objects returned here must be treated as read-only.
func NewTFJobLister ¶
func NewTFJobLister(indexer cache.Indexer) TFJobLister
NewTFJobLister returns a new TFJobLister.
type TFJobListerExpansion ¶
type TFJobListerExpansion interface{}
TFJobListerExpansion allows custom methods to be added to TFJobLister.
type TFJobNamespaceLister ¶
type TFJobNamespaceLister interface {
// List lists all TFJobs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.TFJob, err error)
// Get retrieves the TFJob from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.TFJob, error)
TFJobNamespaceListerExpansion
}
TFJobNamespaceLister helps list and get TFJobs. All objects returned here must be treated as read-only.
type TFJobNamespaceListerExpansion ¶
type TFJobNamespaceListerExpansion interface{}
TFJobNamespaceListerExpansion allows custom methods to be added to TFJobNamespaceLister.
type XGBoostJobLister ¶
type XGBoostJobLister interface {
// List lists all XGBoostJobs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.XGBoostJob, err error)
// XGBoostJobs returns an object that can list and get XGBoostJobs.
XGBoostJobs(namespace string) XGBoostJobNamespaceLister
XGBoostJobListerExpansion
}
XGBoostJobLister helps list XGBoostJobs. All objects returned here must be treated as read-only.
func NewXGBoostJobLister ¶
func NewXGBoostJobLister(indexer cache.Indexer) XGBoostJobLister
NewXGBoostJobLister returns a new XGBoostJobLister.
type XGBoostJobListerExpansion ¶
type XGBoostJobListerExpansion interface{}
XGBoostJobListerExpansion allows custom methods to be added to XGBoostJobLister.
type XGBoostJobNamespaceLister ¶
type XGBoostJobNamespaceLister interface {
// List lists all XGBoostJobs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.XGBoostJob, err error)
// Get retrieves the XGBoostJob from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.XGBoostJob, error)
XGBoostJobNamespaceListerExpansion
}
XGBoostJobNamespaceLister helps list and get XGBoostJobs. All objects returned here must be treated as read-only.
type XGBoostJobNamespaceListerExpansion ¶
type XGBoostJobNamespaceListerExpansion interface{}
XGBoostJobNamespaceListerExpansion allows custom methods to be added to XGBoostJobNamespaceLister.